From 502676c24a6889051b82de1697596ccfeed77f65 Mon Sep 17 00:00:00 2001
From: xue <>
Date: Sun, 4 Jun 2006 15:33:50 +0000
Subject: Some minor documentation change. Changed TControl::onBubbleEvent() to
TControl::bubbleEvent()
---
framework/Web/UI/WebControls/TDataBoundControl.php | 8 ++++----
1 file changed, 4 insertions(+), 4 deletions(-)
(limited to 'framework/Web/UI/WebControls/TDataBoundControl.php')
diff --git a/framework/Web/UI/WebControls/TDataBoundControl.php b/framework/Web/UI/WebControls/TDataBoundControl.php
index 9e6ecbf3..09023b66 100644
--- a/framework/Web/UI/WebControls/TDataBoundControl.php
+++ b/framework/Web/UI/WebControls/TDataBoundControl.php
@@ -128,7 +128,7 @@ abstract class TDataBoundControl extends TWebControl
}
/**
- * @return boolean if databind has been invoked in the previous page request
+ * @return boolean whether databind has been invoked in the previous page request
*/
protected function getIsDataBound()
{
@@ -272,7 +272,7 @@ abstract class TDataBoundControl extends TWebControl
}
/**
* Sets page's OnPreLoad event handler as {@link onPagePreLoad}.
* If viewstate is disabled and the current request is a postback,
* {@link setRequiresDataBinding RequiresDataBinding} will be set true.
* This method overrides the parent implementation.
@@ -282,7 +282,7 @@ abstract class TDataBoundControl extends TWebControl
{
parent::onInit($param);
$page=$this->getPage();
- $page->attachEventHandler('OnPreLoad',array($this,'onPagePreLoad'));
+ $page->attachEventHandler('OnPreLoad',array($this,'pagePreLoad'));
}
/**
@@ -291,7 +291,7 @@ abstract class TDataBoundControl extends TWebControl
* @param mixed event sender
* @param TEventParameter event parameter
*/
- public function onPagePreLoad($sender,$param)
+ public function pagePreLoad($sender,$param)
{
$this->_initialized=true;
$isPostBack=$this->getPage()->getIsPostBack();
@@ -272,7 +272,7 @@ abstract class TDataBoundControl extends TWebControl
}
/**
- * Sets page's OnPreLoad event handler as {@link onPagePreLoad}.
+ * Sets page's OnPreLoad event handler as {@link pagePreLoad}.
* If viewstate is disabled and the current request is a postback,
* {@link setRequiresDataBinding RequiresDataBinding} will be set true.
--
cgit v1.2.3